@@ -20,15 +20,9 @@ import unittest
 
 def test_suite():
     names = [
-        "apply",
-        "candidates",
         "debian",
         "probers",
         "proposal",
-        "publish",
-        "recipe",
-        "run",
-        "utils",
         "workspace",
     ]
     module_names = [__name__ + ".test_" + name for name in names]
